@@ -1,3 +1,4 @@
+import copy
 import sys
 import uuid
 
@@ -79,6 +80,12 @@ class Params(object):
     def reset(self):
         self._bound_params = {}
 
+    def clone(self):
+        params = Params(prefix=self.prefix, key=self.key)
+        params._bound_params = copy.deepcopy(self._bound_params)
+
+        return params
+
     @property
     def bound_params(self):
         return OrderedDict(sorted(self._bound_params.items()))
@@ -466,6 +473,14 @@ class Pypher(with_metaclass(_Link)):
 
         return self
 
+    def clone(self):
+        clone = copy.deepcopy(self)
+        params = self.params
+        clone.params = Params(prefix=params.prefix, key=params.key)
+        clone.params += params
+
+        return clone
+
 
 class _BaseLink(Pypher):
     _CLEAR_PRECEEDING_WS = False
@@ -662,6 +677,39 @@ class Raw(Statement):
         return '{args}'.format(args=args)
 
 
+class Conditional(Func):
+    _ADD_PRECEEDING_WS = True
+    _ADD_SUCEEDING_WS = True
+    _SEPARATOR = ', '
+
+    def __unicode__(self):
+        parts = []
+
+        for arg in self.args:
+            if isinstance(arg, (Pypher, Partial)):
+                arg.parent = self.parent
+                value = str(arg)
+            else:
+                param = self.bind_param(arg)
+                value = param.placeholder
+
+            parts.append(value)
+
+        parts = self._SEPARATOR.join(parts)
+
+        return '({})'.format(parts)
+
+
+class ConditionalAND(Conditional):
+    _SEPARATOR = ' AND '
+    _ALIASES = ['CAND', 'COND_AND']
+
+
+class ConditionalOR(Conditional):
+    _SEPARATOR = ' OR '
+    _ALIASES = ['COR', 'COND_OR']
+
+
 class List(_BaseLink):
     _ADD_PRECEEDING_WS = False
     _CLEAR_PRECEEDING_WS = True
